@@ -277,7 +277,7 @@ class ModifiableSpanSelector(SpanSelector):
         SpanSelector.__init__(self, ax, onselect, direction=direction,
                               useblit=useblit, span_stays=False, **kwargs)
         # The tolerance in points to pick the rectangle sizes
-        self.tolerance = 1
+        self.tolerance = 2
         self.on_move_cid = None
         self._range = None
         self.step_ax = None
@@ -419,7 +419,8 @@ class ModifiableSpanSelector(SpanSelector):
     def release(self, event):
         """When the button is released, the span stays in the screen and the
         iteractivity machinery passes to modify mode"""
-        if self.pressv is None or (self.ignore(event) and not self._button_down):
+        if self.pressv is None or (self.ignore(
+                event) and not self._button_down):
             return
         self._button_down = False
         self.update_range()
@@ -568,6 +569,14 @@ class ModifiableSpanSelector(SpanSelector):
             return
         x_increment = self._get_mouse_position(event) - self.pressv
         if self.step_ax is not None:
+            if (self.bounds_check  
+                and self._range[0] <= self.step_ax.low_value
+                and self._get_mouse_position(event) <= self.pressv):
+                return
+            if (self.bounds_check
+                and self._range[1] >= self.step_ax.high_value
+                and self._get_mouse_position(event) >= self.pressv):
+                return
             if self.snap_position:
                 rem = x_increment % self.step_ax.scale
                 if rem / self.step_ax.scale < 0.5:
